@@ -129,14 +129,14 @@ def _get_cookiejar(authorize_from_browser):
             raise EnvironmentError("Could not load cookie from browser. "
                                    "Please login in website via browser before run this code"
                                    "\n  So far the following browsers are supported: "
-                                   "Chrome，Firefox, Opera, Edge, Chromium")
+                                   "Chrome,Firefox, Opera, Edge, Chromium")
     return cj
 
 
 def _handle_status(r, url, local_size, file_name, file_path):
     # returns (True, '') : downloaded entirely
     # returns (False,'') : error! break download
-    # returns (False, url) : 301,302
+    # returns (False, url) : 301,302,303
     # returns None: continue to download
 
     global support_resume, pbar, remote_size
@@ -192,7 +192,7 @@ def _handle_status(r, url, local_size, file_name, file_path):
         tqdm.write('>>> The server has accepted your request but has not yet processed it. '
                    'Please redownload it later')
         return False, ''
-    elif r.status_code in [301, 302]:
+    elif r.status_code in [301, 302, 303]:
         url_new = r.headers['Location']
         tqdm.write(f'>>> Waring: the website has redirected to {url_new}')
         return False, url_new
@@ -211,8 +211,9 @@ def _handle_status(r, url, local_size, file_name, file_path):
         return False, ''
 
 
-def download_data(url, folder=None, authorize_from_browser=False, file_name=None,
-                  client=None, allow_redirects=False, retry=0):
+def download_data(url, folder=None, file_name=None,
+                  client=None, follow_redirects=False, retry=0,
+                  authorize_from_browser=False):
     '''Download a single file.
 
     Parameters:
@@ -224,7 +225,7 @@ def download_data(url, folder=None, authorize_from_browser=False, file_name=None
     authorize_from_browser: bool
         Whether to load cookies used by your web browser for authorization.
         This means you can use python to download data by logining in to website 
-        via browser (So far the following browsers are supported: Chrome，Firefox, 
+        via browser (So far the following browsers are supported: Chrome,Firefox, 
         Opera, Edge, Chromium"). It will be very usefull when website doesn't support
         "HTTP Basic Auth". Default is False.
     file_name: str
@@ -232,7 +233,7 @@ def download_data(url, folder=None, authorize_from_browser=False, file_name=None
         file_name can be the absolute path if folder is None.
     client: httpx.Client() object
         client maintaining connection. Default None
-    allow_redirects: bool
+    follow_redirects: bool
         Enables or disables HTTP redirects
     retry: int 
         number of reconnections when status code is 503
@@ -248,13 +249,13 @@ def download_data(url, folder=None, authorize_from_browser=False, file_name=None
     cj = _get_cookiejar(authorize_from_browser)
 
     r = client.get(url, headers=headers, timeout=120,
-                   allow_redirects=allow_redirects, cookies=cj)
+                   follow_redirects=follow_redirects, cookies=cj)
     r.close()
 
-    if not file_name:
+    if file_name is None:
         file_name = _parse_file_name(r)
 
-    if folder:
+    if folder is not None:
         file_path = os.path.join(folder, file_name)
     else:
         file_path = os.path.abspath(file_name)
@@ -267,10 +268,10 @@ def download_data(url, folder=None, authorize_from_browser=False, file_name=None
         if status:  # downloaded entirely
             return True
         elif status == False:
-            if url_new:  # 301,302
+            if url_new:  # 301,302, 303
                 return download_data(url_new, folder=folder, file_name=file_name,
                                      authorize_from_browser=authorize_from_browser,
-                                     allow_redirects=True, client=client)
+                                     follow_redirects=True, client=client)
             elif retry > 0:
                 return download_data(url, folder=folder, file_name=file_name,
                                      authorize_from_browser=authorize_from_browser,
@@ -315,7 +316,7 @@ def download_data(url, folder=None, authorize_from_browser=False, file_name=None
             return True
 
 
-def download_datas(urls, folder=None, authorize_from_browser=False, file_names=None):
+def download_datas(urls, folder=None, file_names=None, authorize_from_browser=False):
     '''download data from a list like object which containing urls.
     This function will download files one by one.
 
@@ -328,7 +329,7 @@ def download_datas(urls, folder=None, authorize_from_browser=False, file_names=N
     authorize_from_browser: bool
         Whether to load cookies used by your web browser for authorization.
         This means you can use python to download data by logining in to website 
-        via browser (So far the following browsers are supported: Chrome，Firefox, 
+        via browser (So far the following browsers are supported: Chrome,Firefox, 
         Opera, Edge, Chromium"). It will be very usefull when website doesn't support
         "HTTP Basic Auth". Default is False.
     file_names: iterator
@@ -354,7 +355,7 @@ def download_datas(urls, folder=None, authorize_from_browser=False, file_names=N
     '''
     client = httpx.Client(timeout=None)
     for i, url in enumerate(urls):
-        if file_names:
+        if file_names is not None:
             download_data(url, folder, file_name=file_names[i], client=client,
                           authorize_from_browser=authorize_from_browser)
         else:
@@ -366,8 +367,8 @@ def _mp_download_data(args):
     return download_data(*args)
 
 
-def mp_download_datas(urls, folder=None,  authorize_from_browser=False, file_names=None,
-                      ncore=None, desc=''):
+def mp_download_datas(urls, folder=None, file_names=None, ncore=None, desc='',
+                       follow_redirects=False, retry=0, authorize_from_browser=False):
     '''download data from a list like object which containing urls.
     This function will download multiple files simultaneously using multiprocess.
 
@@ -380,12 +381,12 @@ def mp_download_datas(urls, folder=None,  authorize_from_browser=False, file_nam
     authorize_from_browser: bool
         Whether to load cookies used by your web browser for authorization.
         This means you can use python to download data by logining in to website 
-        via browser (So far the following browsers are supported: Chrome，Firefox, 
-        Opera, Edge, Chromium"). It will be very usefull when website doesn't support
+        via browser (So far the following browsers are supported: Chrome,Firefox, 
+        Opera, Edge, Chromium"). It will be very useful when website doesn't support
         "HTTP Basic Auth". Default is False.
     file_names: iterator
         iterator contains names of files. Leaving it None if you want the program to parse
-        them from website. file_names can cantain the absolute paths if folder is None.
+        them from website. file_names can contain the absolute paths if folder is None.
     ncore: int
         Number of cores for parallel processing. If ncore is None then the number returned
         by os.cpu_count() is used. Default None.
@@ -419,11 +420,13 @@ def mp_download_datas(urls, folder=None,  authorize_from_browser=False, file_nam
     pbar = tqdm(total=len(urls), desc=desc, dynamic_ncols=True)
 
     with mp.Pool(ncore) as pool:
-        if file_names:
-            args = [(urls[i], folder, authorize_from_browser, file_names[i])
-                    for i in range(len(urls))]
+        if file_names is not None:
+            args = [(urls[i], folder, file_names[i], None, 
+                     follow_redirects, retry, authorize_from_browser)
+                    for i in range(len(urls))]  # Need to put other parameters in right places
         else:
-            args = [(urls[i], folder, authorize_from_browser)
+            args = [(urls[i], folder, file_names, None, 
+                     follow_redirects, retry, authorize_from_browser)
                     for i in range(len(urls))]
 
         for i in pool.imap_unordered(_mp_download_data, args):
@@ -431,7 +434,7 @@ def mp_download_datas(urls, folder=None,  authorize_from_browser=False, file_nam
 
 
 async def _download_data(client, url, folder=None, file_name=None,
-                         authorize_from_browser=False, allow_redirects=False, retry=0):
+                         follow_redirects=False, retry=0, authorize_from_browser=False):
     global support_resume, pbar, remote_size
 
     headers = {'Range': 'bytes=0-4'}
@@ -440,13 +443,13 @@ async def _download_data(client, url, folder=None, file_name=None,
     cj = _get_cookiejar(authorize_from_browser)
     # auth = get_netrc_auth(url)
 
-    r = await client.get(url, headers=headers, timeout=120, allow_redirects=allow_redirects, cookies=cj)
-    r.close()
+    r = await client.get(url, headers=headers, timeout=120, follow_redirects=follow_redirects, cookies=cj)
+    # r.close()
     # r = await client.head(url, headers=headers, auth=auth, timeout=120)
-    if not file_name:
+    if file_name is None:
         file_name = _parse_file_name(r)
 
-    if folder:
+    if folder is not None:
         if not os.path.exists(folder):
             os.makedirs(folder)
         file_path = os.path.join(folder, file_name)
@@ -462,10 +465,10 @@ async def _download_data(client, url, folder=None, file_name=None,
         if status:  # downloaded entirely
             return True
         elif status == False:
-            if url_new:  # 301,302
+            if url_new:  # 301,302, 303
                 return await _download_data(client, url_new, folder=folder,
                                             authorize_from_browser=authorize_from_browser,
-                                            file_name=file_name, allow_redirects=True)
+                                            file_name=file_name, follow_redirects=True)
             elif retry > 0:
                 return await _download_data(client, url, folder=folder,
                                             authorize_from_browser=authorize_from_browser,
@@ -506,25 +509,25 @@ async def _download_data(client, url, folder=None, file_name=None,
                     file_name,
                     _unit_formater(speed, 'B/s'),
                     _unit_formater(local_size, 'B')))
-            r.close()
+            # r.close()
             return True
 
 
-async def creat_tasks(urls, folder, authorize_from_browser, file_names, limit, desc, allow_redirects, retry):
+async def creat_tasks(urls, folder, authorize_from_browser, file_names, limit, desc, follow_redirects, retry):
     limits = httpx.Limits(max_keepalive_connections=limit,
                           max_connections=limit)
     async with httpx.AsyncClient(limits=limits, timeout=None, verify=False) as client:
-        if file_names:
+        if file_names is not None:
             tasks = [asyncio.ensure_future(_download_data(client, url, folder,
                                                           authorize_from_browser=authorize_from_browser,
                                                           file_name=file_names[i],
-                                                          allow_redirects=allow_redirects,
+                                                          follow_redirects=follow_redirects,
                                                           retry=retry))
                      for i, url in enumerate(urls)]
         else:
             tasks = [asyncio.ensure_future(_download_data(client, url, folder,
                                                           authorize_from_browser=authorize_from_browser,
-                                                          allow_redirects=allow_redirects,
+                                                          follow_redirects=follow_redirects,
                                                           retry=retry))
                      for url in urls]
 
@@ -537,8 +540,8 @@ async def creat_tasks(urls, folder, authorize_from_browser, file_names, limit, d
             await coroutine
 
 
-def async_download_datas(urls, folder=None, authorize_from_browser=False,
-                         file_names=None, limit=30, desc='', allow_redirects=False, retry=0):
+def async_download_datas(urls, folder=None, file_names=None, limit=30, desc='',
+                         follow_redirects=False, retry=0, authorize_from_browser=False):
     '''Download multiple files simultaneously.
 
     Parameters:
@@ -550,7 +553,7 @@ def async_download_datas(urls, folder=None, authorize_from_browser=False,
     authorize_from_browser: bool
         Whether to load cookies used by your web browser for authorization.
         This means you can use python to download data by logining in to website 
-        via browser (So far the following browsers are supported: Chrome，Firefox, 
+        via browser (So far the following browsers are supported: Chrome,Firefox, 
         Opera, Edge, Chromium"). It will be very usefull when website doesn't support
         "HTTP Basic Auth". Default is False.
     file_names: iterator
@@ -560,7 +563,7 @@ def async_download_datas(urls, folder=None, authorize_from_browser=False,
         the number of files downloading simultaneously
     desc: str
         description of datas downloading
-    allow_redirects: bool
+    follow_redirects: bool
         Enables or disables HTTP redirects
     retry: int
         number of reconnections when status code is 503
@@ -586,7 +589,7 @@ def async_download_datas(urls, folder=None, authorize_from_browser=False,
     loop = asyncio.SelectorEventLoop(selector)
     try:
         loop.run_until_complete(creat_tasks(
-            urls, folder, authorize_from_browser, file_names, limit, desc, allow_redirects, retry))
+            urls, folder, authorize_from_browser, file_names, limit, desc, follow_redirects, retry))
     finally:
         loop.close()
 
@@ -627,7 +630,7 @@ def status_ok(urls, limit=200, authorize_from_browser=False, timeout=60):
     authorize_from_browser: bool
         Whether to load cookies used by your web browser for authorization.
         This means you can use python to download data by logining in to website 
-        via browser (So far the following browsers are supported: Chrome，Firefox, 
+        via browser (So far the following browsers are supported: Chrome,Firefox, 
         Opera, Edge, Chromium"). It will be very usefull when website doesn't support
         "HTTP Basic Auth". Default is False.
     timeout: int
